# QCloud Signature Version 3 Signing Process with python requests

QCloud TC3-HMAC-SHA256 signature is basically a fork of AWSv4. This library can help you to call API directly
using Requests, so you can avoid the freaking other library, if you want.